@@ -185,7 +185,7 @@ def gopa_stat(gopa_df, p_val:float = 0.05, adj:str = 'None', dir:str = 'results'
     adj = adj.upper()
     
     if not os.path.exists(dir):
-        os.mkdir(dir)
+        os.makedirs(dir)
         
     df3 = gopa_df
     df4 = pd.DataFrame()     
@@ -255,7 +255,7 @@ def gene_network(gopa_df:pd.DataFrame, p_val:float = 0.05, adj:str = 'None', dir
     adj = adj.upper()
     
     if not os.path.exists(dir):
-        os.mkdir(dir)
+        os.makedirs(dir)
     
     df7 = gopa_df.pivot_table(index = "GOPa", columns = 'gen', values = 'n',  fill_value = 0)
                
@@ -308,9 +308,9 @@ def gene_network(gopa_df:pd.DataFrame, p_val:float = 0.05, adj:str = 'None', dir
     for i in range(0,len(net_df['Gen1'])):
         G.add_edge(net_df.iloc[i,0], net_df.iloc[i,1], weight = net_df.iloc[i,3])
     
-    net = Network(notebook=True, height = '1000px', width = '1200px')
+    net = Network(notebook=True, height = '1000px', width = '1600px')
     net.from_nx(G)
-    net.repulsion(node_distance=120, spring_length=220)
+    net.repulsion(node_distance=130, spring_length=230)
     net.show_buttons(filter_=['nodes', 'physics'])
     net.show(str(dir + str('/' + name + '.html')))
 
@@ -324,8 +324,8 @@ def gopa_network(gopa_df:pd.DataFrame, p_val:float = 0.05, adj:str = 'None', dir
   
     adj = adj.upper()
     
-    if not os.path.exists('results'):
-        os.mkdir('results')
+    if not os.path.exists(dir):
+        os.makedirs(dir)
         
     df6 = gopa_df
     pathways = df6[df6['type'] == 'pathway']
@@ -675,9 +675,9 @@ def gopa_network(gopa_df:pd.DataFrame, p_val:float = 0.05, adj:str = 'None', dir
                             
     
     
-    net = Network(notebook=True, height = '1000px', width = '1200px')
+    net = Network(notebook=True, height = '1000px', width = '1600px')
     net.from_nx(combine_nx)
-    net.repulsion(node_distance=120, spring_length=220)
+    net.repulsion(node_distance=130, spring_length=230)
     net.show_buttons(filter_=['nodes', 'physics'])
     net.show(str(dir + str('/' + name + '.html')))
 
